summaryrefslogtreecommitdiffstats
path: root/libkdepim/kmailcompletion.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/kmailcompletion.cpp')
-rw-r--r--libkdepim/kmailcompletion.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/libkdepim/kmailcompletion.cpp b/libkdepim/kmailcompletion.cpp
index 98a3cb9ee..7e71ec78c 100644
--- a/libkdepim/kmailcompletion.cpp
+++ b/libkdepim/kmailcompletion.cpp
@@ -44,8 +44,8 @@ TQString KMailCompletion::makeCompletion( const TQString &string )
// this should be in postProcessMatch, but postProcessMatch is const and will not allow nextMatch
if ( !match.isEmpty() ){
const TQString firstMatch( match );
- while ( match.tqfind( TQRegExp( "(@)|(<.*>)" ) ) == -1 ) {
- /* local email do not require @domain part, if match is an address we'll tqfind
+ while ( match.find( TQRegExp( "(@)|(<.*>)" ) ) == -1 ) {
+ /* local email do not require @domain part, if match is an address we'll find
* last+first <match> in m_keyMap and we'll know that match is already a valid email.
*
* Distribution list do not have last+first <match> entry, they will be in mailAddr
@@ -53,7 +53,7 @@ TQString KMailCompletion::makeCompletion( const TQString &string )
const TQStringList &mailAddr = m_keyMap[ match ]; //get all mailAddr for this keyword
bool isEmail = false;
for ( TQStringList::ConstIterator sit ( mailAddr.begin() ), sEnd( mailAddr.end() ); sit != sEnd; ++sit )
- if ( (*sit).tqfind( "<" + match + ">" ) != -1 || (*sit) == match ) {
+ if ( (*sit).find( "<" + match + ">" ) != -1 || (*sit) == match ) {
isEmail = true;
break;
}
@@ -77,7 +77,7 @@ void KMailCompletion::addItemWithKeys( const TQString& email, int weight, const
Q_ASSERT( keyWords != 0 );
for ( TQStringList::ConstIterator it( keyWords->begin() ); it != keyWords->end(); ++it ) {
TQStringList &emailList = m_keyMap[ (*it) ]; //lookup email-list for given keyword
- if ( emailList.tqfind( email ) == emailList.end() ) //add email if not there
+ if ( emailList.find( email ) == emailList.end() ) //add email if not there
emailList.append( email );
addItem( (*it),weight ); //inform KCompletion about keyword
}